Skip inlining clut() with GCC on more platforms.

Bug: skia:9202
Change-Id: I73cfbd3b48813a0ce5e36df2c23d879008f62df9
Reviewed-on: https://skia-review.googlesource.com/c/skcms/+/223700
Commit-Queue: Brian Osman <brianosman@google.com>
Auto-Submit: Mike Klein <mtklein@google.com>
Reviewed-by: Brian Osman <brianosman@google.com>
diff --git a/src/Transform_inl.h b/src/Transform_inl.h
index 799eda0..a8e8aa6 100644
--- a/src/Transform_inl.h
+++ b/src/Transform_inl.h
@@ -608,8 +608,9 @@
 }
 
 // GCC 7.2.0 hits an internal compiler error with -finline-functions (or -O3)
-// when targeting MIPS 64,  I think attempting to inline clut() into exec_ops().
-#if 1 && defined(__GNUC__) && !defined(__clang__) && defined(__mips64)
+// when targeting MIPS 64, i386, or s390x,  I think attempting to inline clut() into exec_ops().
+#if 1 && defined(__GNUC__) && !defined(__clang__) \
+      && (defined(__mips64) || defined(__i386) || defined(__s390x__))
     #define MAYBE_NOINLINE __attribute__((noinline))
 #else
     #define MAYBE_NOINLINE